<?php
namespace app\cms\event;

use think\Controller;

class Admin extends Controller
{
    protected $query = [];
	
	public function _initialize()
    {
        //$this->request->filter('trim,strip_tags,htmlspecialchars');
        
        $this->query = $this->request->param();
        
		parent::_initialize();
	}

	public function index()
    {
        $themes = DcThemeOption('cms');
    
        $items  = DcFormItems([
            'theme' => [
                'type'   =>'select', 
                'value'  => config('cms.theme'), 
                'option' => $themes,
            ],
            'theme_wap' => [
                'type'   => 'select',
                'value'  => config('cms.theme_wap'),
                'option' => $themes,
            ],
            'slug_first' => [
                'type'   => 'select',
                'value'  => config('cms.slug_first'),
                'option' => [0=>'关闭',1=>'开启'],
            ],
            'page_size' => [
                'type'        => 'number',
                'value'       => DcEmpty(config('cms.page_size'),30),
                'placeholder' => '',
            ],
            'search_interval' => [
                'type'        => 'number',
                'value'       => intval(config('cms.search_interval')),
                'placeholder' => '',
                'tips'        => lang('search_interval_tips'),
            ],
            'search_max' => [
                'type'        => 'number',
                'value'       => intval(config('cms.search_max')),
                'placeholder' => '',
                'tips'        => lang('search_max_tips'),
            ],
            'search_hot' => [
                'type'        => 'text',
                'value'       => config('cms.search_hot'),
                'rows'        => 5,
                'placeholder' => '',
                'tips'        => lang('search_hot_tips'),
            ],
            'rewrite_index' => [
                'type'        => 'text', 
                'value'       => DcEmpty(config('cms.rewrite_index'), 'cms$'),
                'placeholder' => '',
                'tips'        => 'cms$',
            ],
            'rewrite_category' => [
                'type'        => 'text', 
                'value'       => config('cms.rewrite_category'),
                'placeholder' => '',
                'tips'        => '[:id] [:slug] [:name] [:pageNumber] [:pageSize] [:sortName] [:sortNumber]',
            ],
            'rewrite_tag' => [
                'type'        => 'text',
                'value'       => config('cms.rewrite_tag'),
                'placeholder' => '',
                'tips'        => '[:id] [:slug] [:name] [:pageNumber] [:pageSize] [:sortName] [:sortNumber]',
            ],
            'rewrite_search' => [
                'type'        => 'text',
                'value'       => config('cms.rewrite_search'),
                'placeholder' => '',
                'tips'        => '[:searchText] [:pageNumber] [:pageSize] [:sortName] [:sortNumber]',
            ],
            'rewrite_filter' => [
                'type'        => 'text',
                'value'       => config('cms.rewrite_filter'),
                'placeholder' => '',
                'tips'        => '[:pageNumber] [:pageSize] [:sortName] [:sortNumber] [:cmsTop] [:cmsHot]',
            ],
            'rewrite_detail' => [
                'type'        => 'text',
                'value'       => config('cms.rewrite_detail'),
                'placeholder' => '',
                'tips'        => '[:id] [:slug] [:name]',
            ],
        ]);
        
        $itemsSeo  = DcFormItems([
            'url_suffix'  => [
                'type'        => 'text', 
                'value'       => config('cms.url_suffix'),
                'placeholder' => '',
                'tips'        => '.html|.shtml|.asp|.php|.jsp',
            ],
            'index_title' => [
                'type'        => 'text', 
                'value'       => config('cms.index_title'),
                'placeholder' => '',
                'tips'        => '[siteName] [siteDomain] [pageNumber]',
            ],
            'index_keywords' => [
                'type'        => 'text', 
                'value'       => config('cms.index_keywords'),
                'placeholder' => '',
                'tips'        => '[siteName] [siteDomain] [pageNumber]',
            ],
            'index_description' => [
                'type'        => 'text', 
                'value'       => config('cms.index_description'),
                'placeholder' => '',
                'tips'        => '[siteName] [siteDomain] [pageNumber]',
            ],
            'search_title' => [
                'type'        => 'text', 
                'value'       => config('cms.search_title'),
                'placeholder' => '',
                'tips'        => '[siteName] [siteDomain] [pageNumber] [searchText]',
            ],
            'search_keywords' => [
                'type'        => 'text', 
                'value'       => config('cms.search_keywords'),
                'placeholder' => '',
                'tips'        => '[siteName] [siteDomain] [pageNumber] [searchText]',
            ],
            'search_description' => [
                'type'        => 'text', 
                'value'       => config('cms.search_description'),
                'placeholder' => '',
                'tips'        => '[siteName] [siteDomain] [pageNumber] [searchText]',
            ],
            'maps_title' => [
                'type'        => 'text', 
                'value'       => config('cms.maps_title'),
                'placeholder' => '',
                'tips'        => '[siteName] [siteDomain] [pageNumber] [action]',
            ],
            'maps_keywords' => [
                'type'        => 'text', 
                'value'       => config('cms.maps_keywords'),
                'placeholder' => '',
                'tips'        => '[siteName] [siteDomain] [pageNumber] [action]',
            ],
            'maps_description' => [
                'type'        => 'text', 
                'value'       => config('cms.maps_description'),
                'placeholder' => '',
                'tips'        => '[siteName] [siteDomain] [pageNumber] [action]',
            ],
        ]);
        
        $group = [
            [
                'title' => lang('cms_admin_index'),
                'items' => $items,
            ],
            [    'title' => lang('cms_admin_seo'),
                 'items' => $itemsSeo,
            ],
        ];
        
        $this->assign('group', $group);
        
        return $this->fetch('cms@admin/index');
	}
    
    public function update()
    {
        $status = \daicuo\Op::write(
            input('post.'),
            input('module/s','cms'), 
            input('controll/s','system'),
            input('action/s','config'),
            input('order/d',0),
            input('autoload/s','yes')
        );
		if( !$status ){
		    $this->error(lang('fail'));
        }
        //处理伪静态路由
        $this->configRoute(input('post.'));
        //返回结果
        $this->success(lang('success'));
	}
    
    private function configRoute($post)
    {
        //批量删除路由伪静态
        \daicuo\Op::delete_all([
            'op_name'     => ['eq','site_route'],
            'op_module'   => ['eq','cms'],
            'op_controll' => ['in','index,category,tag,search,filter,detail'],
        ]);
        //批量添加路由伪静态
        $result = \daicuo\Route::save_all([
            [
                'rule'        => $post['rewrite_index'],
                'address'     => 'cms/index/index',
                'method'      => '*',
                'op_module'   => 'cms',
                'op_controll' => 'index',
                'op_action'   => 'index',
            ],
            [
                'rule'        => $post['rewrite_category'],
                'address'     => 'cms/category/index',
                'method'      => '*',
                'op_module'   => 'cms',
                'op_controll' => 'category',
                'op_action'   => 'index',
            ],
            [
                'rule'        => $post['rewrite_tag'],
                'address'     => 'cms/tag/index',
                'method'      => '*',
                'op_module'   => 'cms',
                'op_controll' => 'tag',
                'op_action'   => 'index',
            ],
            [
                'rule'        => $post['rewrite_search'],
                'address'     => 'cms/search/index',
                'method'      => '*',
                'op_module'   => 'cms',
                'op_controll' => 'search',
                'op_action'   => 'index',
            ],
            [
                'rule'        => $post['rewrite_filter'],
                'address'     => 'cms/filter/index',
                'method'      => '*',
                'op_module'   => 'cms',
                'op_controll' => 'filter',
                'op_action'   => 'index',
            ],
            [
                'rule'        => $post['rewrite_detail'],
                'address'     => 'cms/detail/index',
                'method'      => '*',
                'op_module'   => 'cms',
                'op_controll' => 'detail',
                'op_action'   => 'index',
            ],
        ]);
        //清理全局缓存
        DcCache('route_all', null);
    }
	
}