<?php
namespace app\cms\event;

use think\Controller;

class Category extends Controller
{
    protected $query = [];
    
    public function _initialize()
    {
        $this->query = $this->request->param();

        parent::_initialize();
    }
    
    public function create()
    {
        $this->assign('query', $this->query);
        
        $this->assign('items', model('cms/Category','loglic')->items($this->query));

		return $this->fetch('cms@category/create');
    }
    
    public function save()
    {

        config('common.validate_name', 'cms/Category');
        
        config('common.validate_scene', 'save');
        
        config('common.where_slug_unique', ['term_type'=>['eq','cms']]);
        
        $term_id = \daicuo\Term::save(input('post.'));
        
		if($term_id < 1){
			$this->error(\daicuo\Term::getError());
		}
        
		$this->success(lang('success'));
    }
    
    public function delete()
    {
        DcTermDeleteIds(input('id/a'));
        
        $this->success(lang('success'));
    }
    
    public function edit()
    {
        if(!$id = input('id/d',0)){
            $this->error(lang('mustIn'));
        }
        
        //查询数据
        $data = \daicuo\Term::get_id($id, false);
        if( is_null($data) ){
            $this->error(lang('empty'));
        }
        
        //定义变量
        $this->assign('data', $data);
        
        $this->assign('items', model('cms/Category','loglic')->items($data));
        
        return $this->fetch('cms@category/edit');
    }
    
    public function update()
    {
        $data = input('post.');
        if(!$data['term_id']){
            $this->error(lang('mustIn'));
        }
        
        config('common.validate_name', 'cms/Category');
        
        config('common.validate_scene', 'save');
        
        config('common.where_slug_unique', ['term_type'=>['eq','category']]);
        
        if( !\daicuo\Term::update_id($data['term_id'], $data) ){
            $this->error(\daicuo\Info::getError());
        }
        $this->success(lang('success'));
    }
    
    public function preview()
    {
        if( !$id = input('id/d',0) ){
            $this->error(lang('mustIn'));
        }
        //快速查询数据
        $info = \daicuo\Term::get_id($id, false);
        if(!$info){
            $this->error(lang('empty'));
        }
        //去掉后台入口文件
        $url = str_replace($this->request->baseFile(), '', articleUrlCategory($info));
        //跳转至前台
        $this->redirect($url,302);
    }
    
    public function index()
    {
        if( $this->request->isAjax() ){
            //查询参数
            $args = array();
            $args['cache']         = false;
            $args['result']        = 'level';
            $args['type']          = 'category';
            $args['module']        = 'cms';
            //$args['limit']         = input('pageSize/d', 30);
            //$args['page']          = input('pageNumber/d', 1);
            $args['sort']          = input('get.sortName/s','term_id');
            $args['order']         = input('get.sortOrder/s','desc');
            $args['search']        = input('searchText/s','');
            //扩展字段生成查询参数
            $args['meta_query']    = [];
            foreach( DcArrayFilter($this->query, config('custom_fields.term_meta')) as $key=>$value ){
                if($value){
                    array_push($args['meta_query'], ['key'=>['eq',$key],'value'=>['eq',$value]]);
                }
            }
            //自定义查询条件
            if( $where = DcWhereQuery(['term_parent','term_order','term_module','term_status'], 'eq', $this->query) ){
                $args['where'] = $where;
            }
            //数据返回
            if($infos = DcTermSelect($args) ){
                return json($infos);
            }
            return json([]);
		}
        //地址栏参数
        $this->assign('query', $this->query);
        //表单筛选字段
        $this->assign('items', model('cms/Category','loglic')->items($this->query));
        //表格列字段
        $this->assign('columns', model('cms/Category','loglic')->columns($this->query));
        //加载模板
		return $this->fetch('cms@category/index');
	}
}