<?php
namespace app\cms\loglic;

class Friend
{
    // 错误信息
    protected $error = '';
    
    /**
     * 获取错误信息
     * @return mixed
     */
    public function getError()
    {
        return $this->error;
    }
    
    /**
    * 表单字段通用属性处理
    * @version 1.0.0 首次引入
    * @param array $data 可选;初始数据;默认：空
    * @return array 表单字段数组列表（DcBuildForm）
    */
    public function items($data=[])
    {
        //获取表单字段列表
        $fields = $this->fields($data);
        //增加字段的相同属性值
        foreach($fields as $key=>$value){
            if(!isset($fields[$key]['class_left'])){
                $fields[$key]['class_left'] = 'col-12';
            }
            if(!isset($fields[$key]['class_right'])){
                $fields[$key]['class_right'] = 'col-12';
            }
            $fields[$key]['class_tips']  = '';
        }
        //表单字段（格式化）
        return DcFormItems($fields);
    }
    
    /**
    * 表格选项通用属性处理
    * @version 1.0.0 首次引入
    * @param array $data 可选;初始数据;默认：空
    * @return array 表格列字段属性（DcBuildTable）
    */
    public function columns($data=[])
    {
        $fields = list_sort_by($this->fields($data), 'order', 'asc', true);
        
        $columns = DcTableColumns($fields);
        
        $columns['operate']['data-events'] = 'daicuo.admin.cms.eventsDialog';
        
        return $columns;
    }
    
    /**
    * 定义文章模型的字段
    * @version 1.0.0 首次引入
    * @param array $data 可选;初始数据;默认：空
    * @return array 表格列字段属性（DcBuildTable）
    */
    public function fields($data)
    {
        $fields = [
            'info_controll' => [
                'type'            => 'hidden',
                'value'           => 'friend',
            ],
            'info_type' => [
                'type'            => 'hidden',
                'value'           => 'link',
            ],
            'info_slug' => [
                'type'            => 'hidden',
                'value'           => DcEmpty($data['info_slug'], uniqid()),
            ],
            'info_status' => [
                'type'            => 'select',
                'value'           => DcEmpty($data['info_status'],'normal'),
                'order'           => 6,
                'option'          => ['normal'=>lang('normal'), 'hidden'=>lang('hidden'), 'private'=>lang('private')],
                'title'           => lang('friend_status'),
                'data-visible'    => false,
            ],
            'info_status_text' => [
                'order'           => 6,
                'data-title'      => lang('friend_status'),
                'data-visible'    => true,
            ],
            'info_id' => [
                'type'            => 'hidden',
                'value'           => $data['info_id'],
                'order'           => 1,
                'data-title'      => lang('article_id'),
                'data-filter'     => false,
                'data-visible'    => true,
                'data-sortable'   => true,
                'data-width'      => '60',
                'data-width-unit' => 'px',
            ],
            'info_name' => [
                'type'            => 'text',
                'value'           => $data['info_name'],
                'order'           => 2,
                'required'        => true,
                'title'           => lang('friend_name'),
                'placeholder'     => lang('friend_name_placeholder'),
                'data-title'      => lang('friend_name'),
                'data-filter'     => false,
                'data-visible'    => true,
                'data-align'      => 'left',
                'data-class'      => 'text-wrap',
                'data-width'      => '35',
                'data-width-unit' => '%',
            ],
            'info_referer' => [
                'type'            => 'text',
                'value'           => $data['info_referer'],
                'order'           => 3,
                'title'           => lang('friend_url'),
                'placeholder'     => lang('friend_url_placeholder'),
                'data-title'      => lang('friend_url'),
                'data-visible'    => true,
                'data-align'      => 'left',
                'data-width'      => '15',
                'data-width-unit' => '%',
            ],
            'info_cover' => [
                'type'            => 'image',
                'value'           => $data['info_cover'],
                'order'           => 4,
                'title'           => lang('friend_cover'),
                'placeholder'     => lang('friend_cover_placeholder'),
                'data-title'      => lang('friend_cover'),
                'data-filter'     => false,
                'data-visible'    => true,
                'data-align'      => 'left',
                'data-width'      => '15',
                'data-width-unit' => '%',
            ],
            'info_order' => [
                'type'            => 'number',
                'value'           => intval($data['info_order']),
                'order'           => 5,
                'data-visible'    => true,
                'data-sortable'   => true,
            ],
            'info_content' => [
                'type'            => 'textarea',
                'value'           => $data['info_content'],
                'order'           => 10,
                'rows'            => 5,
                'title'           => lang('friend_content'),
                'placeholder'     => '',
                'data-title'      => lang('friend_content'),
            ],
            'info_create_time' => [
                'order'           => 7,
                'data-visible'    => true,
                'data-sortable'   => true,
            ],
            'info_update_time' => [
                'order'           => 8,
                'data-visible'    => true,
                'data-sortable'   => true,
            ]
        ];
        return $fields;
    }
}